# == Class: unitrends
#
# Full description of class unitrends here.
#
# === Parameters
#
# Document parameters here.
#
# [*sample_parameter*]
#   Explanation of what this parameter affects and what it defaults to.
#   e.g. "Specify one or more upstream ntp servers as an array."
#
# === Variables
#
# Here you should define a list of variables that this module would require.
#
# [*sample_variable*]
#   Explanation of how this variable affects the funtion of this class and if
#   it has a default. e.g. "The parameter enc_ntp_servers must be set by the
#   External Node Classifier as a comma separated list of hostnames." (Note,
#   global variables should be avoided in favor of class parameters as
#   of Puppet 2.6.)
#
# === Examples
#
#  class { unitrends:
#    servers => [ 'pool.ntp.org', 'ntp.local.company.com' ],
#  }
#
# === Authors
#
# Author Name <sund@unc.edu>
#
# === Copyright
#
# Copyright 2014 Shaun Sundquist, sund@unc.edu
#
class unitrends {
	# determine arch
	$arch=$::hardwaremodel
	notice("Found Platform to be $arch")
	
	# download rpm
	notice("Trying to download... $arch version of rpm")
	
	exec{'retrieve_rpm':
		command => "/usr/bin/wget -q http://ftp.unitrends.com/bp/latest_build/Linux/unitrends-linux-agent-7.4.0-2.2014042910.$arch.rpm -O /tmp/unitrends-linux-agent-7.4.0-2.2014042910.$arch.rpm",
		creates => "/tmp/unitrends-linux-agent-7.4.0-2.2014042910.$arch.rpm",
		}
	
	file{'/tmp/unitrends-linux-agent-7.4.0-2.2014042910.$arch.rpm':
		mode => 0755,
		require => Exec["retrieve_rpm"],
		}
	
	# install rpm
	notice("Installing...")
	
	package { 'unitrends-linux-agent-7.4.0-2.2014042910.$arch':
			provider => rpm,
			ensure   => installed,
			source   => "file:///tmp/unitrends-linux-agent-7.4.0-2.2014042910.$arch.rpm",
			#require  => Package['xinetd.$arch']
	  		}

	
	# confiugure master ini et al
	# copy over template
	notice("Config master.ini...")
	file { '/usr/bp/bpinit/master.ini':
		ensure  => file,
		backup  => false,
		owner   => 'root',
		group   => 'root',
		mode    => '0644',
		content => template("sund-unitrends/master.ini"),
		}
		
	## remove /etc/rc.d/rc5.d/S50notify_fs_event
	notice("Removing rc mynotify ...")
	file { "/etc/rc.d/rc5.d/S50notify_fs_event":
		ensure  => absent,
		}
	
	## comment out /etc/init.d/watchdog -e >/dev/null 2>&1 in root crontab
	notice("Removing mynotify cron job...")
	### below needs puppetlabs/stdlib
	##file_line {
	##	'watchdog_off':
	##	path        => '/var/spool/cron/root',
	##	match       => '/etc/init.d/watchdog',
	##	line        => "#* * * * * /etc/init.d/watchdog -e >/dev/null 2>&1",
	##	}
	
	## doing with exec
	exec { "watchdog_off":
		command => "perl -pi -e 's,\\* \\* \\* \\* \\* /etc/init.d/watchdog -e >/dev/null 2>&1,#* * * * * /etc/init.d/watchdog -e >/dev/null 2>&1,g' /var/spool/cron/root",
		path    => "/usr/local/bin/:/bin/",
		# path    => [ "/usr/local/bin/", "/bin/" ],  # alternative syntax
		}

	
	## sudo killall -e /usr/local/bin/mynotify
	notice("Killing running mynotify jobs...")
	exec { "killall_mynotify":
		command => "killall -e /usr/local/bin/mynotify",
		path    => "/usr/bin:/usr/local/bin/:/bin/",
		# path    => [ "/usr/local/bin/", "/bin/" ],  # alternative syntax
		}
	
	## sudo /etc/init.d/xinetd restart
	notice("Restarting xinetd...")
	service { 'unitrends_xinetd':
		ensure    => true,
		enable     => true,
		restart    => true
		}


}

include unitrends